.. RSAITEHU documentation master file, created by
   sphinx-quickstart on Thu Nov  9 21:22:36 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to RSAITEHU's documentation!
====================================

Some words.

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
Pointcloud Module
=================

.. automodule:: pointcloud
   :members:
   
   .. autosummary::
      
      get_pointcloud_after_substracting_point_cloud
      pointcloud_audit
      pointcloud_sanitize
   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`


